pmm.multiclass: PMM for multiclass variable

View source: R/pmm.R

pmm.multiclassR Documentation

PMM for multiclass variable

Description

PMM for multiclass variable

Usage

pmm.multiclass(yhatobs, yhatmis, yobs, k)

Arguments

yhatobs

The predicted values of observed entries in a variable

yhatmis

The predicted values of missing entries in a variable

yobs

The actual observed values of observed entries in a variable

k

The number of donors.

Value

The matched observed values of all missing entries


mixgb documentation built on Jan. 17, 2026, 5:07 p.m.